@@ -1,7 +1,7 @@
 ;;; ninetyfive.el --- NinetyFive -*- lexical-binding: t; -*-
 ;; Author: NinetyFive
-;; Package-Version: 20251106.1628
-;; Package-Revision: ca72a8f2e071
+;; Package-Version: 20251125.2223
+;; Package-Revision: 0d673ac905c6
 ;; Package-Requires: ((emacs "26.1") (websocket "1.12") (async "1.9.7"))
 ;; Keywords: convenience, productivity
 ;; URL: https://github.com/ninetyfive-gg/ninetyfive.el
@@ -36,6 +36,7 @@
 (require 'async)
 (require 'json)
 (require 'browse-url)
+(require 'url-util)
 
 (defgroup ninetyfive nil
   "NinetyFive completion."
@@ -69,6 +70,9 @@ Values:
   :type 'string
   :group 'ninetyfive)
 
+(defconst ninetyfive-version "0.2.0"
+  "Current NinetyFive package version.")
+
 (defcustom ninetyfive-api-key nil
   "Optional API key for NinetyFive Ultra."
   :type '(choice (const :tag "Unset" nil)
@@ -106,11 +110,24 @@ Values:
   (let* ((base ninetyfive-websocket-url)
          (api (and (stringp ninetyfive-api-key)
                    (> (length ninetyfive-api-key) 0)
-                   ninetyfive-api-key)))
-    (if api
-        (concat base (if (string-match-p "\\?" base) "&" "?")
-                "api_key=" api)
-      base)))
+                   ninetyfive-api-key))
+         (params (append `(("editor" . "emacs")
+                           ("version" . ,ninetyfive-version))
+                         (when api `(("api_key" . ,api)))))
+         (separator (cond
+                     ((string-match-p "\\?" base)
+                      (if (and (> (length base) 0)
+                               (eq (aref base (1- (length base))) ??))
+                          ""
+                        "&"))
+                     (t "?")))
+         (query (mapconcat (lambda (pair)
+                             (format "%s=%s"
+                                     (url-hexify-string (format "%s" (car pair)))
+                                     (url-hexify-string (format "%s" (cdr pair)))))
+                           params
+                           "&")))
+    (concat base separator query)))
 
 (defvar ninetyfive--connected nil
   "Whether we're connected to the WebSocket.")
